@@ -1,6 +1,6 @@
 import enum
 
-__all__ = ['MSAChoices', 'MSAIntegerChoices', 'MSATextChoices']
+__all__ = ["MSAChoices", "MSAIntegerChoices", "MSATextChoices"]
 
 
 class MSAChoicesMeta(enum.EnumMeta):
@@ -11,14 +11,14 @@ class MSAChoicesMeta(enum.EnumMeta):
         for key in classdict._member_names:
             value = classdict[key]
             if (
-                    isinstance(value, (list, tuple)) and
-                    len(value) > 1 and
-                    isinstance(value[-1], (Promise, str))
+                isinstance(value, (list, tuple))
+                and len(value) > 1
+                and isinstance(value[-1], (Promise, str))
             ):
                 *value, label = value
                 value = tuple(value)
             else:
-                label = key.replace('_', ' ').title()
+                label = key.replace("_", " ").title()
             labels.append(label)
             # Use dict.__setitem__() to suppress defenses against double
             # assignment in enum's classdict.
@@ -40,12 +40,12 @@ class MSAChoicesMeta(enum.EnumMeta):
 
     @property
     def names(cls):
-        empty = ['__empty__'] if hasattr(cls, '__empty__') else []
+        empty = ["__empty__"] if hasattr(cls, "__empty__") else []
         return empty + [member.name for member in cls]
 
     @property
     def choices(cls):
-        empty = [(None, cls.__empty__)] if hasattr(cls, '__empty__') else []
+        empty = [(None, cls.__empty__)] if hasattr(cls, "__empty__") else []
         return empty + [(member.value, member.label) for member in cls]
 
     @property
@@ -70,7 +70,6 @@ class MSAChoices(enum.Enum, metaclass=MSAChoicesMeta):
 
 class MSAIntegerChoices(int, MSAChoices):
     """Class for creating enumerated integer choices."""
-    pass
 
 
 class MSATextChoices(str, MSAChoices):
@@ -85,4 +84,3 @@ class Promise:
     Base class for the proxy class created in the closure of the lazy function.
     It's used to recognize promises in code.
     """
-    pass
